summaryrefslogtreecommitdiff
path: root/table_test.go
diff options
context:
space:
mode:
Diffstat (limited to 'table_test.go')
-rw-r--r--table_test.go8
1 files changed, 7 insertions, 1 deletions
diff --git a/table_test.go b/table_test.go
index 0a74b1b..5941c50 100644
--- a/table_test.go
+++ b/table_test.go
@@ -45,6 +45,12 @@ func TestAddTable(t *testing.T) {
assert.EqualError(t, f.addTable("sheet1", "", 1, 1, 0, 0, 0, nil), "invalid cell coordinates [0, 0]")
}
+func TestSetTableHeader(t *testing.T) {
+ f := NewFile()
+ _, err := f.setTableHeader("Sheet1", 1, 0, 1)
+ assert.EqualError(t, err, "invalid cell coordinates [1, 0]")
+}
+
func TestAutoFilter(t *testing.T) {
outFile := filepath.Join("test", "TestAutoFilter%d.xlsx")
@@ -72,7 +78,7 @@ func TestAutoFilter(t *testing.T) {
})
}
// testing AutoFilter with illegal cell coordinates.
assert.EqualError(t, f.AutoFilter("Sheet1", "A", "B1", ""), newCellNameToCoordinatesError("A", newInvalidCellNameError("A")).Error())
assert.EqualError(t, f.AutoFilter("Sheet1", "A1", "B", ""), newCellNameToCoordinatesError("B", newInvalidCellNameError("B")).Error())
}
@@ -72,7 +78,7 @@ func TestAutoFilter(t *testing.T) {
})
}
- // testing AutoFilter with illegal cell coordinates.
+ // Test AutoFilter with illegal cell coordinates.
assert.EqualError(t, f.AutoFilter("Sheet1", "A", "B1", ""), newCellNameToCoordinatesError("A", newInvalidCellNameError("A")).Error())
assert.EqualError(t, f.AutoFilter("Sheet1", "A1", "B", ""), newCellNameToCoordinatesError("B", newInvalidCellNameError("B")).Error())